==> huaweicloudsdkmpc-3.1.111-py2.py3-none-any.whl: huaweicloudsdkmpc/v1/model/notification_config_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NotificationConfigReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'notifications': 'list[Notification]'
    }

    attribute_map = {
        'notifications': 'notifications'
    }

    def __init__(self, notifications=None):
        """NotificationConfigReq

        The model defined in huaweicloud sdk

        :param notifications: 事件通知模板信息 
        :type notifications: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        
        

        self._notifications = None
        self.discriminator = None

        self.notifications = notifications

    @property
    def notifications(self):
        """Gets the notifications of this NotificationConfigReq.

        事件通知模板信息 

        :return: The notifications of this NotificationConfigReq.
        :rtype: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this NotificationConfigReq.

        事件通知模板信息 

        :param notifications: The notifications of this NotificationConfigReq.
        :type notifications: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        self._notifications = notifications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationConfigReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmpc-3.1.147-py2.py3-none-any.whl: huaweicloudsdkmpc/v1/model/notification_config_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NotificationConfigReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'notifications': 'list[Notification]'
    }

    attribute_map = {
        'notifications': 'notifications'
    }

    def __init__(self, notifications=None):
        r"""NotificationConfigReq

        The model defined in huaweicloud sdk

        :param notifications: 事件通知模板信息 
        :type notifications: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        
        

        self._notifications = None
        self.discriminator = None

        self.notifications = notifications

    @property
    def notifications(self):
        r"""Gets the notifications of this NotificationConfigReq.

        事件通知模板信息 

        :return: The notifications of this NotificationConfigReq.
        :rtype: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        r"""Sets the notifications of this NotificationConfigReq.

        事件通知模板信息 

        :param notifications: The notifications of this NotificationConfigReq.
        :type notifications: list[:class:`huaweicloudsdkmpc.v1.Notification`]
        """
        self._notifications = notifications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationConfigReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
